@@ -1,7 +1,7 @@
 from plonetheme.intkBase.browser.interfaces import IIntkBaseLayer
 from plone.theme.interfaces import IDefaultPloneLayer
 from plone.portlets.interfaces import IPortletManager
-
+from plone.app.portlets.interfaces import IColumn
 
 class IThemeSpecific(IDefaultPloneLayer):
     """Marker interface that defines a Zope 3 browser layer.
@@ -11,10 +11,10 @@ class IThemeSpecific(IDefaultPloneLayer):
     """
 
 
-class IFrontPagePortletManagerLeft(IPortletManager):
+class IFrontPagePortletManagerLeft(IPortletManager, IColumn):
     """The first front page view portlet """
     
     
-class IFrontPagePortletManagerRight(IPortletManager):
+class IFrontPagePortletManagerRight(IPortletManager, IColumn):
     """The second front page view portlet """
     
\ No newline at end of file
